@@ -57,9 +57,45 @@ def compute_field_force(layouts, r, force_mesh, force, types, n_types):
             force[ind, d] = force_mesh[t][d].readout(r[ind], layout=layouts[t])
 
 
+def compute_self_energy_q(config, charges, comm=MPI.COMM_WORLD):
+    """Compute the self energy for the interaction due to the Ewald scheme
+    used to compute the electrostatics. The energy is stored in :code:`config`.
+
+    The self interaction energy is given by:
+
+    .. math::
+
+        U_{self} = \\sqrt{\\frac{1}{2\\pi\\sigma^2}} \\sum_{i=1}^{N} q_i^2
+
+    where :math:`q_i` are the charges and :math:`\\sigma` is the half-width
+    of the Gaussian filter.
+
+    Parameters
+    ----------
+    config : Config
+        Configuration object.
+    charges : (N,) numpy.ndarray
+        Array of particle charge values for :code:`N` particles. Local for each
+        MPI rank.
+    comm : mpi4py.Comm
+        MPI communicator to use for rank communication.
+
+    Returns
+    -------
+    field_q_self_energy : float
+        Electrostatic self energy.
+    """
+    elec_conversion_factor = config.coulomb_constant / config.dielectric_const
+
+    prefac = elec_conversion_factor * np.sqrt(1./(2.*np.pi*config.sigma*config.sigma))
+    _squared_charges = charges * charges
+    squared_charges_sum = comm.allreduce(np.sum(_squared_charges))
+    return prefac * squared_charges_sum
+
+
 def compute_field_energy_q(
-    config, phi_q_fourier, elec_energy_field, field_q_energy,
-    comm=MPI.COMM_WORLD,
+    config, phi_q, phi_q_fourier, elec_potential, elec_potential_fourier, 
+    field_q_self_energy, comm=MPI.COMM_WORLD,
 ):
     """Calculate the electrostatic energy from a field configuration
 
@@ -68,65 +104,76 @@ def compute_field_energy_q(
 
     .. math::
 
-        E = \\frac{1}{2}\\int\\mathrm{d}\\mathbf{r}\\,
+        E = \\frac{1}{2\\varepsilon_0 \\varepsilon_r}\\int\\mathrm{d}\\mathbf{r}\\,
             \\rho(\\mathbf{r}) \\Psi(\\mathbf{r}),
 
     where :math:`\\rho(\\mathbf{r})` denotes the charge density at position
-    :math:`\\mathbf{r}`. Through application of Gauss' law and writing
-    :math:`\\Psi` in terms of the electric field :math:`\\mathbf{E}`, this
-    becomes
-
-    .. math::
-
-        E = \\frac{\\varepsilon}{2}\\int\\mathrm{d}\\mathbf{r}\\,
-            \\mathbf{E}\\cdot \\mathbf{E},
-
-    where :math:`\\varepsilon` is the relative dielectric of the simulation
+    :math:`\\mathbf{r}`, :math:`\\varepsilon_0` is the vacuum permittivity 
+    and :math:`\\varepsilon_r` is the relative dielectric of the simulation
     medium.
 
     Parameters
     ----------
     config : Config
         Configuration object.
+    phi_q : pmesh.pm.RealField
+        Pmesh :code:`RealField` object containing the discretized
+        electrostatic potential values in real space on the
+        computational grid. Local for each MPI rank--the full computayional grid
+        is represented by the collective fields of all MPI ranks.
     phi_q_fourier : pmesh.pm.ComplexField
         Pmesh :code:`ComplexField` object containing the discretized
         electrostatic potential values in reciprocal space on the
-        computational grid. Local for each MPI rank--the full computaional grid
+        computational grid. Local for each MPI rank--the full computayional grid
         is represented by the collective fields of all MPI ranks.
-    elec_energy_field : pmesh.pm.ComplexField
-        Pmesh :code:`ComplexField` object for storing calculated discretized
-        electrostatic energy density values in reciprocal space on the
+    elec_potential : pmesh.pm.RealField
+        Pmesh :code:`RealField` object for storing calculated discretized
+        electrostatic potential values in real space on the
         computational grid. Pre-allocated, but empty; any values in this field
         are discarded. Changed in-place. Local for each MPI rank--the full
         computaional grid is represented by the collective fields of all MPI
         ranks.
-    field_q_energy : float
-        Total elecrostatic energy.
+    elec_potential_fourier : pmesh.pm.ComplexField
+        Pmesh :code:`ComplexField` object for storing calculated discretized
+        electrostatic potential values in reciprocal space on the
+        computational grid. Pre-allocated, but empty; any values in this field
+        are discarded. Changed in-place. Local for each MPI rank--the full
+        computaional grid is represented by the collective fields of all MPI
+        ranks.
+    field_q_self_energy : float
+        Electrostatic self energy to be subtracted.
 
     Returns
     -------
-    elec_field_energy : float
+    field_q_energy : float
         Total electrostatic energy.
     """
     elec_conversion_factor = config.coulomb_constant / config.dielectric_const
+    V = np.prod(config.box_size)
+    n_mesh_cells = np.prod(np.full(3, config.mesh_size))
+    volume_per_cell = V / n_mesh_cells
 
-    def transfer_energy(k, v):
+    # solve Poisson equation in Fourier space
+    def poisson_transfer_function(k, v):
         return (
-            4.0 * np.pi * elec_conversion_factor * np.abs(v)**2
+            4. * np.pi * elec_conversion_factor * v
             / k.normp(p=2, zeromode=1)
         )
-
     phi_q_fourier.apply(
-        transfer_energy, kind="wavenumber", out=elec_energy_field
+        poisson_transfer_function, out=elec_potential_fourier
     )
-    V = np.prod(config.box_size)
-    field_q_energy = 0.5 * V * comm.allreduce(np.sum(elec_energy_field.value))
-    return field_q_energy.real
+
+    # get electrostatic potential in real space and compute energy
+    elec_potential_fourier.c2r(out=elec_potential)
+    field_q_energy = 0.5 * volume_per_cell * comm.allreduce(np.sum(phi_q*elec_potential))
+
+    field_q_energy -= field_q_self_energy # subtract self-energy
+    return field_q_energy
 
 
 def update_field_force_q(
     charges, phi_q, phi_q_fourier, elec_field_fourier, elec_field,
-    elec_forces, layout_q, pm, positions, config,
+    elec_forces, layout_q, hamiltonian, pm, positions, config,
 ):
     """Calculate the electrostatic particle-field forces on the grid
 
@@ -216,6 +263,9 @@ def update_field_force_q(
         system. Used as blueprint by :code:`pmesh.pm.paint` and
         :code:`pmesh.pm.readout` for exchange of particle information across
         MPI ranks as necessary.
+    hamiltonian : Hamiltonian
+        Particle-field interaction energy handler object. Defines the
+        grid-independent filtering function, :math:`H`.
     pm : pmesh.pm.ParticleMesh
         Pmesh :code:`ParticleMesh` object interfacing to the CIC window
         function and the PFFT discrete Fourier transform library.
@@ -228,18 +278,19 @@ def update_field_force_q(
     V = np.prod(config.box_size)
     n_mesh_cells = np.prod(np.full(3, config.mesh_size))
     volume_per_cell = V / n_mesh_cells
+    
+    # charges to grid
     pm.paint(positions, layout=layout_q, mass=charges, out=phi_q)
     phi_q /= volume_per_cell
     phi_q.r2c(out=phi_q_fourier)
 
-    def phi_transfer_function(k, v):
-        return v * np.exp(-0.5 * config.sigma**2 * k.normp(p=2, zeromode=1))
-
-    phi_q_fourier.apply(phi_transfer_function, out=phi_q_fourier)
+    # smear charges with filter
+    phi_q_fourier.apply(hamiltonian.H, out=phi_q_fourier)
     phi_q_fourier.c2r(out=phi_q)
+
+    # compute electric field directly from smeared charged densities in Fourier
     n_dimensions = config.box_size.size
     elec_conversion_factor = config.coulomb_constant / config.dielectric_const
-
     for _d in np.arange(n_dimensions):
 
         def poisson_transfer_function(k, v, d=_d):
@@ -252,6 +303,7 @@ def update_field_force_q(
         )
         elec_field_fourier[_d].c2r(out=elec_field[_d])
 
+    # get electrostatic force from electric field
     for _d in np.arange(n_dimensions):
         elec_forces[:, _d] = charges * (
             elec_field[_d].readout(positions, layout=layout_q)
