@@ -59,13 +59,24 @@ class OutDataset:
                 comm=comm
             )
 
+    def is_open(self, comm=MPI.COMM_WORLD):
+        """Check if HDF5 output file is open
+
+        Parameters
+        ----------
+        comm : mpi4py.Comm
+            MPI communicator to use for rank communication.
+        """
+        comm.Barrier()
+        return self.file.__bool__()
+
     def close_file(self, comm=MPI.COMM_WORLD):
         """Closes the HDF5 output file
 
         Parameters
         ----------
         comm : mpi4py.Comm
-            MPI communicator to use for rank commuication.
+            MPI communicator to use for rank communication.
         """
         comm.Barrier()
         self.file.close()
@@ -209,6 +220,8 @@ def store_static(
         n_frames += 1
     if np.mod(config.n_steps, config.n_print) == 1:
         n_frames += 1
+    if n_frames == config.n_steps:
+        n_frames += 1
 
     species = h5md.all_particles.create_dataset(
         "species", (config.n_particles,), dtype="i",
@@ -591,7 +604,7 @@ def store_data(
     ]
     fmt_ = np.array(fmt_)
     
-    # create mask to show only energies > 0
+    # create mask to show only energies != 0
     en_array = np.array([
         field_energy,
         field_q_energy,
@@ -600,7 +613,7 @@ def store_data(
         bond4_energy,
     ])
     mask = np.full_like(fmt_, True, dtype=bool)
-    mask[range(6,11)] = en_array > 0.
+    mask[range(6,11)] = en_array != 0.
 
     header_ = fmt_[mask].shape[0] * "{:>13}"
     if config.initial_energy is None:
