@@ -15,7 +15,8 @@ from .logger import Logger, format_timedelta
 from .file_io import distribute_input, OutDataset, store_static, store_data
 from .field import (compute_field_force, update_field,
                     compute_field_and_kinetic_energy, domain_decomposition,
-                    update_field_force_q, compute_field_energy_q,)
+                    update_field_force_q, compute_field_energy_q,
+                    compute_self_energy_q)
 from .thermostat import (csvr_thermostat, cancel_com_momentum,
                          generate_initial_velocities)
 from .force import dipole_forces_redistribution, prepare_bonds
@@ -133,6 +134,7 @@ def main():
     dihedral_energy = 0.0
     kinetic_energy = 0.0
     field_q_energy = 0.0
+    field_q_self_energy = 0.0
 
     # Ignore numpy numpy.VisibleDeprecationWarning: Creating an ndarray from
     # ragged nested sequences until it is fixed in pmesh
@@ -173,7 +175,10 @@ def main():
         elec_field = [
             pm.create("real", value=0.0) for _ in range(_SPACE_DIM)
         ]  # for force calculation
-        elec_energy_field = pm.create(
+        elec_potential = pm.create(
+            "real", value=0.0
+        )
+        elec_potential_fourier = pm.create(
             "complex", value=0.0
         )
 
@@ -258,15 +263,17 @@ def main():
         )
 
     if charges_flag and config.coulombtype == "PIC_Spectral":
+        field_q_self_energy = compute_self_energy_q(config, charges, comm=comm)
         layout_q = pm.decompose(positions)
         update_field_force_q(
             charges, phi_q, phi_q_fourier, elec_field_fourier, elec_field,
-            elec_forces, layout_q, pm, positions, config,
+            elec_forces, layout_q, hamiltonian, pm, positions, config,
         )
 
         field_q_energy = compute_field_energy_q(
-            config, phi_q_fourier, elec_energy_field, field_q_energy,
-            comm=comm,
+            config, phi_q, phi_q_fourier, elec_potential, 
+            elec_potential_fourier, 
+            field_q_self_energy, comm=comm,
         )
 
     if molecules_flag:
@@ -373,7 +380,7 @@ def main():
             update_field_force_q(
                 dipole_charges, phi_dipoles, phi_dipoles_fourier,
                 dipoles_field_fourier, dipoles_field, dipole_forces,
-                layout_dipoles, pm, dipole_positions, config,
+                layout_dipoles, hamiltonian, pm, dipole_positions, config,
             )
 
             dipole_positions = np.reshape(dipole_positions, (n_tors, 4, 3))
@@ -563,11 +570,13 @@ def main():
                 layout_q = pm.decompose(positions)
                 update_field_force_q(
                     charges, phi_q, phi_q_fourier, elec_field_fourier,
-                    elec_field, elec_forces, layout_q, pm, positions, config,
+                    elec_field, elec_forces, layout_q, hamiltonian, 
+                    pm, positions, config,
                 )
                 field_q_energy = compute_field_energy_q(
-                    config, phi_q_fourier, elec_energy_field, field_q_energy,
-                    comm=comm,
+                    config, phi_q, phi_q_fourier, elec_potential, 
+                    elec_potential_fourier, 
+                    field_q_self_energy, comm=comm,
                 )
 
             if protein_flag and not args.disable_dipole:
@@ -582,7 +591,7 @@ def main():
                 update_field_force_q(
                     dipole_charges, phi_dipoles, phi_dipoles_fourier,
                     dipoles_field_fourier, dipoles_field, dipole_forces,
-                    layout_dipoles, pm, dipole_positions, config,
+                    layout_dipoles, hamiltonian, pm, dipole_positions, config,
                 )
 
                 dipole_positions = np.reshape(dipole_positions, (n_tors, 4, 3))
@@ -764,8 +773,9 @@ def main():
 
                     if charges_flag and config.coulombtype == "PIC_Spectral":
                         field_q_energy = compute_field_energy_q(
-                            config, phi_q_fourier, elec_energy_field,
-                            field_q_energy, comm=comm,
+                            config, phi_q, phi_q_fourier, elec_potential, 
+                            elec_potential_fourier, 
+                            field_q_self_energy, comm=comm,
                         )
                 else:
                     kinetic_energy = comm.allreduce(
@@ -828,12 +838,14 @@ def main():
                 layout_q = pm.decompose(positions)
                 update_field_force_q(
                     charges, phi_q, phi_q_fourier, elec_field_fourier,
-                    elec_field, elec_forces, layout_q, pm, positions, config,
+                    elec_field, elec_forces, layout_q, hamiltonian, pm,
+                    positions, config,
                 )
 
                 field_q_energy = compute_field_energy_q(
-                    config, phi_q_fourier, elec_energy_field, field_q_energy,
-                    comm=comm,
+                    config, phi_q, phi_q_fourier, elec_potential, 
+                    elec_potential_fourier, 
+                    field_q_self_energy, comm=comm,
                 )
 
         else:
